==> mysql-8.0_8.0.23.orig.tar.gz: mysql-8.0.23/components/reference_cache/cache_allocator.h <==
/* Copyright (c) 2020, Oracle and/or its affiliates. All rights reserved.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is also distributed with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have included with MySQL.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <mysql/components/library_mysys/component_malloc_allocator.h>

#ifndef REFERENCE_CACHE_ALLOCATOR_H
#define REFERENCE_CACHE_ALLOCATOR_H

namespace reference_caching {

class Cache_malloced {
 public:
  static void *operator new(std::size_t sz);
  static void operator delete(void *ptr, std::size_t sz);
};

}  // namespace reference_caching

#endif /* REFERENCE_CACHE_ALLOCATOR_H */

==> mysql-9.6.0.tar.gz: mysql-9.6.0/components/reference_cache/cache_allocator.h <==
/* Copyright (c) 2020, 2025, Oracle and/or its affiliates.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2.0,
as published by the Free Software Foundation.

This program is designed to work with certain software (including
but not limited to OpenSSL) that is licensed under separate terms,
as designated in a particular file or component or in included license
documentation.  The authors of MySQL hereby grant you an additional
permission to link the program and your derivative works with the
separately licensed software that they have either included with
the program or referenced in the documentation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License, version 2.0, for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#include <mysql/components/library_mysys/component_malloc_allocator.h>

#ifndef REFERENCE_CACHE_ALLOCATOR_H
#define REFERENCE_CACHE_ALLOCATOR_H

namespace reference_caching {

class Cache_malloced {
 public:
  static void *operator new(std::size_t sz);
  static void operator delete(void *ptr, std::size_t sz);
};

}  // namespace reference_caching

#endif /* REFERENCE_CACHE_ALLOCATOR_H */
